"""
URL configuration for public_sentiment project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.db import router
from django.urls import path
from drf_yasg import openapi
from drf_yasg.views import get_schema_view
from rest_framework import permissions, routers
from django.contrib import admin
from rest_framework import routers
from django.conf.urls import include
from rest_framework.routers import DefaultRouter
from rest_framework.schemas.views import SchemaView
from tornado.web import url

from web import views
from web.controller.html_parser_controller import HtmlParserController
from web.controller.schedule_controller import SchedulerController

# Swagger documentation setup
# schema_view = get_schema_view(
#     openapi.Info(
#         title="舆情系统API",
#         default_version='v1',
#         description="舆情系统API",
#         terms_of_service="https://www.google.com/policies/terms/",
#         contact=openapi.Contact(email="contact@snippets.local"),
#         license=openapi.License(name="BSD License"),
#     ),
#     public=True,
#     permission_classes=(permissions.AllowAny,),
# )


# 重要的是如下三行
from rest_framework.schemas import get_schema_view
from rest_framework_swagger.renderers import SwaggerUIRenderer, OpenAPIRenderer

schema_view = get_schema_view(title='Users API', renderer_classes=[OpenAPIRenderer, SwaggerUIRenderer])

router = routers.DefaultRouter()
# router.register('users', views.UserViewSet, base_name='user')
# router.register('groups', views.GroupViewSet, base_name='group')

urlpatterns = [
    path('admin/', admin.site.urls),
    path('', include(router.urls)),
    path('api-auth/', include('rest_framework.urls', namespace='rest_framework')),
    path('docs/', schema_view, name='docs'),

    path('admin/', admin.site.urls),
    path('api/v1/htmlParser/parseHtml', HtmlParserController().parse_html),
    path('api/v1/scheduler/create', SchedulerController().create),
    path('api/v1/scheduler/delete', SchedulerController().delete),
    path('api/v1/scheduler/update', SchedulerController().update),
    path('api/v1/scheduler/search', SchedulerController().search),
]
